@@ -15,12 +15,12 @@ use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::DomainSnapshot v0.0.4;
+package Sys::Async::Virt::DomainSnapshot v0.0.5;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.4;
+use Protocol::Sys::Virt::Remote::XDR v0.0.5;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -122,18 +122,28 @@ Sys::Async::Virt::DomainSnapshot - Client side proxy to remote LibVirt domain sn
 
 =head1 VERSION
 
-v0.0.4
+v0.0.5
 
 =head1 SYNOPSIS
 
+  use Future::AsyncAwait;
+
+  my $domain = await $virt->domain_lookup_by_name( 'domain' );
+  my $snap   = await $domain->snapshot_lookup_by_name( 'snap' );
+  say await $snap->num_children;
+
 =head1 DESCRIPTION
 
 =head1 EVENTS
 
+There are no (LibVirt) events available for snapshots.
+
 =head1 CONSTRUCTOR
 
 =head2 new
 
+Not to be called directly. Various API calls return instances of this type.
+
 =head1 METHODS
 
 =head2 delete
@@ -262,4 +272,4 @@ L<LibVirt|https://libvirt.org>, L<Sys::Virt>
   Copyright (C) 2024 Erik Huelsmann
 
 All rights reserved. This program is free software;
-you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+you can redistribute it and/or modify it under the same terms as Perl itself.
